@@ -24,13 +24,18 @@ Usage::
     scan_paginator: ScanPaginator = client.get_paginator("scan")
     ```
 """
-import sys
 from datetime import datetime
 from decimal import Decimal
 from typing import Any, Dict, Iterator, List, Set, Union
 
 from botocore.paginate import Paginator as Boto3Paginator
 
+from mypy_boto3_dynamodb.literals import (
+    BackupTypeFilter,
+    ConditionalOperator,
+    ReturnConsumedCapacity,
+    Select,
+)
 from mypy_boto3_dynamodb.type_defs import (
     ConditionTypeDef,
     ListBackupsOutputTypeDef,
@@ -41,12 +46,6 @@ from mypy_boto3_dynamodb.type_defs import (
     ScanOutputTypeDef,
 )
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
-
-
 __all__ = (
     "ListBackupsPaginator",
     "ListTablesPaginator",
@@ -58,7 +57,7 @@ __all__ = (
 
 class ListBackupsPaginator(Boto3Paginator):
     """
-    [Paginator.ListBackups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/dynamodb.html#DynamoDB.Paginator.ListBackups)
+    [Paginator.ListBackups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/dynamodb.html#DynamoDB.Paginator.ListBackups)
     """
 
     def paginate(
@@ -66,59 +65,57 @@ class ListBackupsPaginator(Boto3Paginator):
         TableName: str = None,
         TimeRangeLowerBound: datetime = None,
         TimeRangeUpperBound: datetime = None,
-        BackupType: Literal["USER", "SYSTEM", "AWS_BACKUP", "ALL"] = None,
+        BackupType: BackupTypeFilter = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListBackupsOutputTypeDef]:
         """
-        [ListBackups.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/dynamodb.html#DynamoDB.Paginator.ListBackups.paginate)
+        [ListBackups.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/dynamodb.html#DynamoDB.Paginator.ListBackups.paginate)
         """
 
 
 class ListTablesPaginator(Boto3Paginator):
     """
-    [Paginator.ListTables documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/dynamodb.html#DynamoDB.Paginator.ListTables)
+    [Paginator.ListTables documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/dynamodb.html#DynamoDB.Paginator.ListTables)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListTablesOutputTypeDef]:
         """
-        [ListTables.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/dynamodb.html#DynamoDB.Paginator.ListTables.paginate)
+        [ListTables.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/dynamodb.html#DynamoDB.Paginator.ListTables.paginate)
         """
 
 
 class ListTagsOfResourcePaginator(Boto3Paginator):
     """
-    [Paginator.ListTagsOfResource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/dynamodb.html#DynamoDB.Paginator.ListTagsOfResource)
+    [Paginator.ListTagsOfResource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/dynamodb.html#DynamoDB.Paginator.ListTagsOfResource)
     """
 
     def paginate(
         self, ResourceArn: str, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListTagsOfResourceOutputTypeDef]:
         """
-        [ListTagsOfResource.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/dynamodb.html#DynamoDB.Paginator.ListTagsOfResource.paginate)
+        [ListTagsOfResource.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/dynamodb.html#DynamoDB.Paginator.ListTagsOfResource.paginate)
         """
 
 
 class QueryPaginator(Boto3Paginator):
     """
-    [Paginator.Query documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/dynamodb.html#DynamoDB.Paginator.Query)
+    [Paginator.Query documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/dynamodb.html#DynamoDB.Paginator.Query)
     """
 
     def paginate(
         self,
         TableName: str,
         IndexName: str = None,
-        Select: Literal[
-            "ALL_ATTRIBUTES", "ALL_PROJECTED_ATTRIBUTES", "SPECIFIC_ATTRIBUTES", "COUNT"
-        ] = None,
+        Select: Select = None,
         AttributesToGet: List[str] = None,
         ConsistentRead: bool = None,
         KeyConditions: Dict[str, ConditionTypeDef] = None,
         QueryFilter: Dict[str, ConditionTypeDef] = None,
-        ConditionalOperator: Literal["AND", "OR"] = None,
+        ConditionalOperator: ConditionalOperator = None,
         ScanIndexForward: bool = None,
-        ReturnConsumedCapacity: Literal["INDEXES", "TOTAL", "NONE"] = None,
+        ReturnConsumedCapacity: ReturnConsumedCapacity = None,
         ProjectionExpression: str = None,
         FilterExpression: str = None,
         KeyConditionExpression: str = None,
@@ -145,13 +142,13 @@ class QueryPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[QueryOutputTypeDef]:
         """
-        [Query.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/dynamodb.html#DynamoDB.Paginator.Query.paginate)
+        [Query.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/dynamodb.html#DynamoDB.Paginator.Query.paginate)
         """
 
 
 class ScanPaginator(Boto3Paginator):
     """
-    [Paginator.Scan documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/dynamodb.html#DynamoDB.Paginator.Scan)
+    [Paginator.Scan documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/dynamodb.html#DynamoDB.Paginator.Scan)
     """
 
     def paginate(
@@ -159,12 +156,10 @@ class ScanPaginator(Boto3Paginator):
         TableName: str,
         IndexName: str = None,
         AttributesToGet: List[str] = None,
-        Select: Literal[
-            "ALL_ATTRIBUTES", "ALL_PROJECTED_ATTRIBUTES", "SPECIFIC_ATTRIBUTES", "COUNT"
-        ] = None,
+        Select: Select = None,
         ScanFilter: Dict[str, ConditionTypeDef] = None,
-        ConditionalOperator: Literal["AND", "OR"] = None,
-        ReturnConsumedCapacity: Literal["INDEXES", "TOTAL", "NONE"] = None,
+        ConditionalOperator: ConditionalOperator = None,
+        ReturnConsumedCapacity: ReturnConsumedCapacity = None,
         TotalSegments: int = None,
         Segment: int = None,
         ProjectionExpression: str = None,
@@ -193,5 +188,5 @@ class ScanPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ScanOutputTypeDef]:
         """
-        [Scan.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/dynamodb.html#DynamoDB.Paginator.Scan.paginate)
+        [Scan.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/dynamodb.html#DynamoDB.Paginator.Scan.paginate)
         """
