@@ -14,7 +14,6 @@ Usage::
     my_table: dynamodb_resources.Table = resource.Table(...)
 ```
 """
-import sys
 from datetime import datetime
 from decimal import Decimal
 from typing import Any, Dict, Iterator, List, Set, Union
@@ -24,6 +23,14 @@ from boto3.dynamodb.table import BatchWriter
 from boto3.resources.base import ServiceResource as Boto3ServiceResource
 from boto3.resources.collection import ResourceCollection
 
+from mypy_boto3_dynamodb.literals import (
+    BillingMode,
+    ConditionalOperator,
+    ReturnConsumedCapacity,
+    ReturnItemCollectionMetrics,
+    ReturnValue,
+    Select,
+)
 from mypy_boto3_dynamodb.type_defs import (
     AttributeDefinitionTypeDef,
     AttributeValueUpdateTypeDef,
@@ -51,18 +58,12 @@ from mypy_boto3_dynamodb.type_defs import (
     WriteRequestTypeDef,
 )
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
-
-
 __all__ = ("DynamoDBServiceResource", "Table", "ServiceResourceTablesCollection")
 
 
 class ServiceResourceTablesCollection(ResourceCollection):
     """
-    [ServiceResource.tables documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/dynamodb.html#DynamoDB.ServiceResource.tables)
+    [ServiceResource.tables documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/dynamodb.html#DynamoDB.ServiceResource.tables)
     """
 
     def all(self) -> "ServiceResourceTablesCollection":
@@ -88,7 +89,7 @@ class ServiceResourceTablesCollection(ResourceCollection):
 
 class Table(Boto3ServiceResource):
     """
-    [Table documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/dynamodb.html#DynamoDB.ServiceResource.Table)
+    [Table documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/dynamodb.html#DynamoDB.ServiceResource.Table)
     """
 
     attribute_definitions: List[Any]
@@ -116,12 +117,12 @@ class Table(Boto3ServiceResource):
 
     def batch_writer(self, overwrite_by_pkeys: List[str] = None) -> BatchWriter:
         """
-        [Table.batch_writer documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/dynamodb.html#DynamoDB.Table.batch_writer)
+        [Table.batch_writer documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/dynamodb.html#DynamoDB.Table.batch_writer)
         """
 
     def delete(self) -> DeleteTableOutputTypeDef:
         """
-        [Table.delete documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/dynamodb.html#DynamoDB.Table.delete)
+        [Table.delete documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/dynamodb.html#DynamoDB.Table.delete)
         """
 
     def delete_item(
@@ -146,10 +147,10 @@ class Table(Boto3ServiceResource):
             ],
         ],
         Expected: Dict[str, ExpectedAttributeValueTypeDef] = None,
-        ConditionalOperator: Literal["AND", "OR"] = None,
-        ReturnValues: Literal["NONE", "ALL_OLD", "UPDATED_OLD", "ALL_NEW", "UPDATED_NEW"] = None,
-        ReturnConsumedCapacity: Literal["INDEXES", "TOTAL", "NONE"] = None,
-        ReturnItemCollectionMetrics: Literal["SIZE", "NONE"] = None,
+        ConditionalOperator: ConditionalOperator = None,
+        ReturnValues: ReturnValue = None,
+        ReturnConsumedCapacity: ReturnConsumedCapacity = None,
+        ReturnItemCollectionMetrics: ReturnItemCollectionMetrics = None,
         ConditionExpression: str = None,
         ExpressionAttributeNames: Dict[str, str] = None,
         ExpressionAttributeValues: Dict[
@@ -173,12 +174,12 @@ class Table(Boto3ServiceResource):
         ] = None,
     ) -> DeleteItemOutputTypeDef:
         """
-        [Table.delete_item documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/dynamodb.html#DynamoDB.Table.delete_item)
+        [Table.delete_item documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/dynamodb.html#DynamoDB.Table.delete_item)
         """
 
     def get_available_subresources(self) -> List[str]:
         """
-        [Table.get_available_subresources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/dynamodb.html#DynamoDB.Table.get_available_subresources)
+        [Table.get_available_subresources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/dynamodb.html#DynamoDB.Table.get_available_subresources)
         """
 
     def get_item(
@@ -204,17 +205,17 @@ class Table(Boto3ServiceResource):
         ],
         AttributesToGet: List[str] = None,
         ConsistentRead: bool = None,
-        ReturnConsumedCapacity: Literal["INDEXES", "TOTAL", "NONE"] = None,
+        ReturnConsumedCapacity: ReturnConsumedCapacity = None,
         ProjectionExpression: str = None,
         ExpressionAttributeNames: Dict[str, str] = None,
     ) -> GetItemOutputTypeDef:
         """
-        [Table.get_item documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/dynamodb.html#DynamoDB.Table.get_item)
+        [Table.get_item documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/dynamodb.html#DynamoDB.Table.get_item)
         """
 
     def load(self) -> None:
         """
-        [Table.load documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/dynamodb.html#DynamoDB.Table.load)
+        [Table.load documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/dynamodb.html#DynamoDB.Table.load)
         """
 
     def put_item(
@@ -239,10 +240,10 @@ class Table(Boto3ServiceResource):
             ],
         ],
         Expected: Dict[str, ExpectedAttributeValueTypeDef] = None,
-        ReturnValues: Literal["NONE", "ALL_OLD", "UPDATED_OLD", "ALL_NEW", "UPDATED_NEW"] = None,
-        ReturnConsumedCapacity: Literal["INDEXES", "TOTAL", "NONE"] = None,
-        ReturnItemCollectionMetrics: Literal["SIZE", "NONE"] = None,
-        ConditionalOperator: Literal["AND", "OR"] = None,
+        ReturnValues: ReturnValue = None,
+        ReturnConsumedCapacity: ReturnConsumedCapacity = None,
+        ReturnItemCollectionMetrics: ReturnItemCollectionMetrics = None,
+        ConditionalOperator: ConditionalOperator = None,
         ConditionExpression: str = None,
         ExpressionAttributeNames: Dict[str, str] = None,
         ExpressionAttributeValues: Dict[
@@ -266,21 +267,19 @@ class Table(Boto3ServiceResource):
         ] = None,
     ) -> PutItemOutputTypeDef:
         """
-        [Table.put_item documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/dynamodb.html#DynamoDB.Table.put_item)
+        [Table.put_item documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/dynamodb.html#DynamoDB.Table.put_item)
         """
 
     def query(
         self,
         IndexName: str = None,
-        Select: Literal[
-            "ALL_ATTRIBUTES", "ALL_PROJECTED_ATTRIBUTES", "SPECIFIC_ATTRIBUTES", "COUNT"
-        ] = None,
+        Select: Select = None,
         AttributesToGet: List[str] = None,
         Limit: int = None,
         ConsistentRead: bool = None,
         KeyConditions: Dict[str, ConditionTypeDef] = None,
         QueryFilter: Dict[str, ConditionTypeDef] = None,
-        ConditionalOperator: Literal["AND", "OR"] = None,
+        ConditionalOperator: ConditionalOperator = None,
         ScanIndexForward: bool = None,
         ExclusiveStartKey: Dict[
             str,
@@ -301,7 +300,7 @@ class Table(Boto3ServiceResource):
                 None,
             ],
         ] = None,
-        ReturnConsumedCapacity: Literal["INDEXES", "TOTAL", "NONE"] = None,
+        ReturnConsumedCapacity: ReturnConsumedCapacity = None,
         ProjectionExpression: str = None,
         FilterExpression: Union[str, ConditionBase] = None,
         KeyConditionExpression: Union[str, ConditionBase] = None,
@@ -327,12 +326,12 @@ class Table(Boto3ServiceResource):
         ] = None,
     ) -> QueryOutputTypeDef:
         """
-        [Table.query documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/dynamodb.html#DynamoDB.Table.query)
+        [Table.query documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/dynamodb.html#DynamoDB.Table.query)
         """
 
     def reload(self) -> None:
         """
-        [Table.reload documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/dynamodb.html#DynamoDB.Table.reload)
+        [Table.reload documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/dynamodb.html#DynamoDB.Table.reload)
         """
 
     def scan(
@@ -340,11 +339,9 @@ class Table(Boto3ServiceResource):
         IndexName: str = None,
         AttributesToGet: List[str] = None,
         Limit: int = None,
-        Select: Literal[
-            "ALL_ATTRIBUTES", "ALL_PROJECTED_ATTRIBUTES", "SPECIFIC_ATTRIBUTES", "COUNT"
-        ] = None,
+        Select: Select = None,
         ScanFilter: Dict[str, ConditionTypeDef] = None,
-        ConditionalOperator: Literal["AND", "OR"] = None,
+        ConditionalOperator: ConditionalOperator = None,
         ExclusiveStartKey: Dict[
             str,
             Union[
@@ -364,7 +361,7 @@ class Table(Boto3ServiceResource):
                 None,
             ],
         ] = None,
-        ReturnConsumedCapacity: Literal["INDEXES", "TOTAL", "NONE"] = None,
+        ReturnConsumedCapacity: ReturnConsumedCapacity = None,
         TotalSegments: int = None,
         Segment: int = None,
         ProjectionExpression: str = None,
@@ -392,13 +389,13 @@ class Table(Boto3ServiceResource):
         ConsistentRead: bool = None,
     ) -> ScanOutputTypeDef:
         """
-        [Table.scan documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/dynamodb.html#DynamoDB.Table.scan)
+        [Table.scan documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/dynamodb.html#DynamoDB.Table.scan)
         """
 
     def update(
         self,
         AttributeDefinitions: List["AttributeDefinitionTypeDef"] = None,
-        BillingMode: Literal["PROVISIONED", "PAY_PER_REQUEST"] = None,
+        BillingMode: BillingMode = None,
         ProvisionedThroughput: "ProvisionedThroughputTypeDef" = None,
         GlobalSecondaryIndexUpdates: List[GlobalSecondaryIndexUpdateTypeDef] = None,
         StreamSpecification: "StreamSpecificationTypeDef" = None,
@@ -406,7 +403,7 @@ class Table(Boto3ServiceResource):
         ReplicaUpdates: List[ReplicationGroupUpdateTypeDef] = None,
     ) -> "_Table":
         """
-        [Table.update documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/dynamodb.html#DynamoDB.Table.update)
+        [Table.update documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/dynamodb.html#DynamoDB.Table.update)
         """
 
     def update_item(
@@ -432,10 +429,10 @@ class Table(Boto3ServiceResource):
         ],
         AttributeUpdates: Dict[str, AttributeValueUpdateTypeDef] = None,
         Expected: Dict[str, ExpectedAttributeValueTypeDef] = None,
-        ConditionalOperator: Literal["AND", "OR"] = None,
-        ReturnValues: Literal["NONE", "ALL_OLD", "UPDATED_OLD", "ALL_NEW", "UPDATED_NEW"] = None,
-        ReturnConsumedCapacity: Literal["INDEXES", "TOTAL", "NONE"] = None,
-        ReturnItemCollectionMetrics: Literal["SIZE", "NONE"] = None,
+        ConditionalOperator: ConditionalOperator = None,
+        ReturnValues: ReturnValue = None,
+        ReturnConsumedCapacity: ReturnConsumedCapacity = None,
+        ReturnItemCollectionMetrics: ReturnItemCollectionMetrics = None,
         UpdateExpression: str = None,
         ConditionExpression: str = None,
         ExpressionAttributeNames: Dict[str, str] = None,
@@ -460,17 +457,17 @@ class Table(Boto3ServiceResource):
         ] = None,
     ) -> UpdateItemOutputTypeDef:
         """
-        [Table.update_item documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/dynamodb.html#DynamoDB.Table.update_item)
+        [Table.update_item documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/dynamodb.html#DynamoDB.Table.update_item)
         """
 
     def wait_until_exists(self) -> None:
         """
-        [Table.wait_until_exists documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/dynamodb.html#DynamoDB.Table.wait_until_exists)
+        [Table.wait_until_exists documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/dynamodb.html#DynamoDB.Table.wait_until_exists)
         """
 
     def wait_until_not_exists(self) -> None:
         """
-        [Table.wait_until_not_exists documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/dynamodb.html#DynamoDB.Table.wait_until_not_exists)
+        [Table.wait_until_not_exists documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/dynamodb.html#DynamoDB.Table.wait_until_not_exists)
         """
 
 
@@ -479,33 +476,33 @@ _Table = Table
 
 class DynamoDBServiceResource(Boto3ServiceResource):
     """
-    [DynamoDB.ServiceResource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/dynamodb.html#DynamoDB.ServiceResource)
+    [DynamoDB.ServiceResource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/dynamodb.html#DynamoDB.ServiceResource)
     """
 
     tables: ServiceResourceTablesCollection
 
     def Table(self, name: str) -> _Table:
         """
-        [ServiceResource.Table documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/dynamodb.html#DynamoDB.ServiceResource.Table)
+        [ServiceResource.Table documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/dynamodb.html#DynamoDB.ServiceResource.Table)
         """
 
     def batch_get_item(
         self,
         RequestItems: Dict[str, "KeysAndAttributesTypeDef"],
-        ReturnConsumedCapacity: Literal["INDEXES", "TOTAL", "NONE"] = None,
+        ReturnConsumedCapacity: ReturnConsumedCapacity = None,
     ) -> BatchGetItemOutputTypeDef:
         """
-        [ServiceResource.batch_get_item documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/dynamodb.html#DynamoDB.ServiceResource.batch_get_item)
+        [ServiceResource.batch_get_item documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/dynamodb.html#DynamoDB.ServiceResource.batch_get_item)
         """
 
     def batch_write_item(
         self,
         RequestItems: Dict[str, List["WriteRequestTypeDef"]],
-        ReturnConsumedCapacity: Literal["INDEXES", "TOTAL", "NONE"] = None,
-        ReturnItemCollectionMetrics: Literal["SIZE", "NONE"] = None,
+        ReturnConsumedCapacity: ReturnConsumedCapacity = None,
+        ReturnItemCollectionMetrics: ReturnItemCollectionMetrics = None,
     ) -> BatchWriteItemOutputTypeDef:
         """
-        [ServiceResource.batch_write_item documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/dynamodb.html#DynamoDB.ServiceResource.batch_write_item)
+        [ServiceResource.batch_write_item documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/dynamodb.html#DynamoDB.ServiceResource.batch_write_item)
         """
 
     def create_table(
@@ -515,17 +512,17 @@ class DynamoDBServiceResource(Boto3ServiceResource):
         KeySchema: List["KeySchemaElementTypeDef"],
         LocalSecondaryIndexes: List[LocalSecondaryIndexTypeDef] = None,
         GlobalSecondaryIndexes: List[GlobalSecondaryIndexTypeDef] = None,
-        BillingMode: Literal["PROVISIONED", "PAY_PER_REQUEST"] = None,
+        BillingMode: BillingMode = None,
         ProvisionedThroughput: "ProvisionedThroughputTypeDef" = None,
         StreamSpecification: "StreamSpecificationTypeDef" = None,
         SSESpecification: SSESpecificationTypeDef = None,
         Tags: List["TagTypeDef"] = None,
     ) -> _Table:
         """
-        [ServiceResource.create_table documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/dynamodb.html#DynamoDB.ServiceResource.create_table)
+        [ServiceResource.create_table documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/dynamodb.html#DynamoDB.ServiceResource.create_table)
         """
 
     def get_available_subresources(self) -> List[str]:
         """
-        [ServiceResource.get_available_subresources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/dynamodb.html#DynamoDB.ServiceResource.get_available_subresources)
+        [ServiceResource.get_available_subresources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/dynamodb.html#DynamoDB.ServiceResource.get_available_subresources)
         """
