@@ -14,10 +14,34 @@ from datetime import datetime
 from decimal import Decimal
 from typing import Any, Dict, List, Set, Union
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
+from mypy_boto3_dynamodb.literals import (
+    AttributeAction,
+    BackupStatus,
+    BackupType,
+    BatchStatementErrorCodeEnum,
+    BillingMode,
+    ComparisonOperator,
+    ContinuousBackupsStatus,
+    ContributorInsightsStatus,
+    DestinationStatus,
+    ExportFormat,
+    ExportStatus,
+    GlobalTableStatus,
+    IndexStatus,
+    KeyType,
+    PointInTimeRecoveryStatus,
+    ProjectionType,
+    ReplicaStatus,
+    ReturnValuesOnConditionCheckFailure,
+    S3SseAlgorithm,
+    ScalarAttributeType,
+    SSEStatus,
+    SSEType,
+    StreamViewType,
+    TableStatus,
+    TimeToLiveStatus,
+)
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -176,7 +200,7 @@ ArchivalSummaryTypeDef = TypedDict(
 )
 
 AttributeDefinitionTypeDef = TypedDict(
-    "AttributeDefinitionTypeDef", {"AttributeName": str, "AttributeType": Literal["S", "N", "B"]}
+    "AttributeDefinitionTypeDef", {"AttributeName": str, "AttributeType": ScalarAttributeType}
 )
 
 AutoScalingPolicyDescriptionTypeDef = TypedDict(
@@ -280,8 +304,8 @@ _RequiredBackupDetailsTypeDef = TypedDict(
     {
         "BackupArn": str,
         "BackupName": str,
-        "BackupStatus": Literal["CREATING", "DELETED", "AVAILABLE"],
-        "BackupType": Literal["USER", "SYSTEM", "AWS_BACKUP"],
+        "BackupStatus": BackupStatus,
+        "BackupType": BackupType,
         "BackupCreationDateTime": datetime,
     },
 )
@@ -306,32 +330,15 @@ BackupSummaryTypeDef = TypedDict(
         "BackupName": str,
         "BackupCreationDateTime": datetime,
         "BackupExpiryDateTime": datetime,
-        "BackupStatus": Literal["CREATING", "DELETED", "AVAILABLE"],
-        "BackupType": Literal["USER", "SYSTEM", "AWS_BACKUP"],
+        "BackupStatus": BackupStatus,
+        "BackupType": BackupType,
         "BackupSizeBytes": int,
     },
     total=False,
 )
 
 BatchStatementErrorTypeDef = TypedDict(
-    "BatchStatementErrorTypeDef",
-    {
-        "Code": Literal[
-            "ConditionalCheckFailed",
-            "ItemCollectionSizeLimitExceeded",
-            "RequestLimitExceeded",
-            "ValidationError",
-            "ProvisionedThroughputExceeded",
-            "TransactionConflict",
-            "ThrottlingError",
-            "InternalServerError",
-            "ResourceNotFound",
-            "AccessDenied",
-            "DuplicateItem",
-        ],
-        "Message": str,
-    },
-    total=False,
+    "BatchStatementErrorTypeDef", {"Code": BatchStatementErrorCodeEnum, "Message": str}, total=False
 )
 
 BatchStatementResponseTypeDef = TypedDict(
@@ -364,10 +371,7 @@ BatchStatementResponseTypeDef = TypedDict(
 
 BillingModeSummaryTypeDef = TypedDict(
     "BillingModeSummaryTypeDef",
-    {
-        "BillingMode": Literal["PROVISIONED", "PAY_PER_REQUEST"],
-        "LastUpdateToPayPerRequestDateTime": datetime,
-    },
+    {"BillingMode": BillingMode, "LastUpdateToPayPerRequestDateTime": datetime},
     total=False,
 )
 
@@ -426,7 +430,7 @@ _OptionalConditionCheckTypeDef = TypedDict(
                 None,
             ],
         ],
-        "ReturnValuesOnConditionCheckFailure": Literal["ALL_OLD", "NONE"],
+        "ReturnValuesOnConditionCheckFailure": ReturnValuesOnConditionCheckFailure,
     },
     total=False,
 )
@@ -452,7 +456,7 @@ ConsumedCapacityTypeDef = TypedDict(
 
 _RequiredContinuousBackupsDescriptionTypeDef = TypedDict(
     "_RequiredContinuousBackupsDescriptionTypeDef",
-    {"ContinuousBackupsStatus": Literal["ENABLED", "DISABLED"]},
+    {"ContinuousBackupsStatus": ContinuousBackupsStatus},
 )
 _OptionalContinuousBackupsDescriptionTypeDef = TypedDict(
     "_OptionalContinuousBackupsDescriptionTypeDef",
@@ -469,13 +473,7 @@ class ContinuousBackupsDescriptionTypeDef(
 
 ContributorInsightsSummaryTypeDef = TypedDict(
     "ContributorInsightsSummaryTypeDef",
-    {
-        "TableName": str,
-        "IndexName": str,
-        "ContributorInsightsStatus": Literal[
-            "ENABLING", "ENABLED", "DISABLING", "DISABLED", "FAILED"
-        ],
-    },
+    {"TableName": str, "IndexName": str, "ContributorInsightsStatus": ContributorInsightsStatus},
     total=False,
 )
 
@@ -608,7 +606,7 @@ _OptionalDeleteTypeDef = TypedDict(
                 None,
             ],
         ],
-        "ReturnValuesOnConditionCheckFailure": Literal["ALL_OLD", "NONE"],
+        "ReturnValuesOnConditionCheckFailure": ReturnValuesOnConditionCheckFailure,
     },
     total=False,
 )
@@ -624,7 +622,7 @@ ExportDescriptionTypeDef = TypedDict(
     "ExportDescriptionTypeDef",
     {
         "ExportArn": str,
-        "ExportStatus": Literal["IN_PROGRESS", "COMPLETED", "FAILED"],
+        "ExportStatus": ExportStatus,
         "StartTime": datetime,
         "EndTime": datetime,
         "ExportManifest": str,
@@ -635,11 +633,11 @@ ExportDescriptionTypeDef = TypedDict(
         "S3Bucket": str,
         "S3BucketOwner": str,
         "S3Prefix": str,
-        "S3SseAlgorithm": Literal["AES256", "KMS"],
+        "S3SseAlgorithm": S3SseAlgorithm,
         "S3SseKmsKeyId": str,
         "FailureCode": str,
         "FailureMessage": str,
-        "ExportFormat": Literal["DYNAMODB_JSON", "ION"],
+        "ExportFormat": ExportFormat,
         "BilledSizeBytes": int,
         "ItemCount": int,
     },
@@ -647,9 +645,7 @@ ExportDescriptionTypeDef = TypedDict(
 )
 
 ExportSummaryTypeDef = TypedDict(
-    "ExportSummaryTypeDef",
-    {"ExportArn": str, "ExportStatus": Literal["IN_PROGRESS", "COMPLETED", "FAILED"]},
-    total=False,
+    "ExportSummaryTypeDef", {"ExportArn": str, "ExportStatus": ExportStatus}, total=False
 )
 
 FailureExceptionTypeDef = TypedDict(
@@ -698,7 +694,7 @@ GlobalSecondaryIndexDescriptionTypeDef = TypedDict(
         "IndexName": str,
         "KeySchema": List["KeySchemaElementTypeDef"],
         "Projection": "ProjectionTypeDef",
-        "IndexStatus": Literal["CREATING", "UPDATING", "DELETING", "ACTIVE"],
+        "IndexStatus": IndexStatus,
         "Backfilling": bool,
         "ProvisionedThroughput": "ProvisionedThroughputDescriptionTypeDef",
         "IndexSizeBytes": int,
@@ -725,7 +721,7 @@ GlobalTableDescriptionTypeDef = TypedDict(
         "ReplicationGroup": List["ReplicaDescriptionTypeDef"],
         "GlobalTableArn": str,
         "CreationDateTime": datetime,
-        "GlobalTableStatus": Literal["CREATING", "ACTIVE", "DELETING", "UPDATING"],
+        "GlobalTableStatus": GlobalTableStatus,
         "GlobalTableName": str,
     },
     total=False,
@@ -791,7 +787,7 @@ ItemResponseTypeDef = TypedDict(
 )
 
 KeySchemaElementTypeDef = TypedDict(
-    "KeySchemaElementTypeDef", {"AttributeName": str, "KeyType": Literal["HASH", "RANGE"]}
+    "KeySchemaElementTypeDef", {"AttributeName": str, "KeyType": KeyType}
 )
 
 _RequiredKeysAndAttributesTypeDef = TypedDict(
@@ -840,13 +836,7 @@ class KeysAndAttributesTypeDef(
 
 KinesisDataStreamDestinationTypeDef = TypedDict(
     "KinesisDataStreamDestinationTypeDef",
-    {
-        "StreamArn": str,
-        "DestinationStatus": Literal[
-            "ENABLING", "ACTIVE", "DISABLING", "DISABLED", "ENABLE_FAILED"
-        ],
-        "DestinationStatusDescription": str,
-    },
+    {"StreamArn": str, "DestinationStatus": DestinationStatus, "DestinationStatusDescription": str},
     total=False,
 )
 
@@ -876,7 +866,7 @@ LocalSecondaryIndexInfoTypeDef = TypedDict(
 PointInTimeRecoveryDescriptionTypeDef = TypedDict(
     "PointInTimeRecoveryDescriptionTypeDef",
     {
-        "PointInTimeRecoveryStatus": Literal["ENABLED", "DISABLED"],
+        "PointInTimeRecoveryStatus": PointInTimeRecoveryStatus,
         "EarliestRestorableDateTime": datetime,
         "LatestRestorableDateTime": datetime,
     },
@@ -885,7 +875,7 @@ PointInTimeRecoveryDescriptionTypeDef = TypedDict(
 
 ProjectionTypeDef = TypedDict(
     "ProjectionTypeDef",
-    {"ProjectionType": Literal["ALL", "KEYS_ONLY", "INCLUDE"], "NonKeyAttributes": List[str]},
+    {"ProjectionType": ProjectionType, "NonKeyAttributes": List[str]},
     total=False,
 )
 
@@ -983,7 +973,7 @@ _OptionalPutTypeDef = TypedDict(
                 None,
             ],
         ],
-        "ReturnValuesOnConditionCheckFailure": Literal["ALL_OLD", "NONE"],
+        "ReturnValuesOnConditionCheckFailure": ReturnValuesOnConditionCheckFailure,
     },
     total=False,
 )
@@ -1000,15 +990,7 @@ ReplicaAutoScalingDescriptionTypeDef = TypedDict(
         "GlobalSecondaryIndexes": List["ReplicaGlobalSecondaryIndexAutoScalingDescriptionTypeDef"],
         "ReplicaProvisionedReadCapacityAutoScalingSettings": "AutoScalingSettingsDescriptionTypeDef",
         "ReplicaProvisionedWriteCapacityAutoScalingSettings": "AutoScalingSettingsDescriptionTypeDef",
-        "ReplicaStatus": Literal[
-            "CREATING",
-            "CREATION_FAILED",
-            "UPDATING",
-            "DELETING",
-            "ACTIVE",
-            "REGION_DISABLED",
-            "INACCESSIBLE_ENCRYPTION_CREDENTIALS",
-        ],
+        "ReplicaStatus": ReplicaStatus,
     },
     total=False,
 )
@@ -1017,15 +999,7 @@ ReplicaDescriptionTypeDef = TypedDict(
     "ReplicaDescriptionTypeDef",
     {
         "RegionName": str,
-        "ReplicaStatus": Literal[
-            "CREATING",
-            "CREATION_FAILED",
-            "UPDATING",
-            "DELETING",
-            "ACTIVE",
-            "REGION_DISABLED",
-            "INACCESSIBLE_ENCRYPTION_CREDENTIALS",
-        ],
+        "ReplicaStatus": ReplicaStatus,
         "ReplicaStatusDescription": str,
         "ReplicaStatusPercentProgress": str,
         "KMSMasterKeyId": str,
@@ -1040,7 +1014,7 @@ ReplicaGlobalSecondaryIndexAutoScalingDescriptionTypeDef = TypedDict(
     "ReplicaGlobalSecondaryIndexAutoScalingDescriptionTypeDef",
     {
         "IndexName": str,
-        "IndexStatus": Literal["CREATING", "UPDATING", "DELETING", "ACTIVE"],
+        "IndexStatus": IndexStatus,
         "ProvisionedReadCapacityAutoScalingSettings": "AutoScalingSettingsDescriptionTypeDef",
         "ProvisionedWriteCapacityAutoScalingSettings": "AutoScalingSettingsDescriptionTypeDef",
     },
@@ -1068,7 +1042,7 @@ _RequiredReplicaGlobalSecondaryIndexSettingsDescriptionTypeDef = TypedDict(
 _OptionalReplicaGlobalSecondaryIndexSettingsDescriptionTypeDef = TypedDict(
     "_OptionalReplicaGlobalSecondaryIndexSettingsDescriptionTypeDef",
     {
-        "IndexStatus": Literal["CREATING", "UPDATING", "DELETING", "ACTIVE"],
+        "IndexStatus": IndexStatus,
         "ProvisionedReadCapacityUnits": int,
         "ProvisionedReadCapacityAutoScalingSettings": "AutoScalingSettingsDescriptionTypeDef",
         "ProvisionedWriteCapacityUnits": int,
@@ -1127,15 +1101,7 @@ _RequiredReplicaSettingsDescriptionTypeDef = TypedDict(
 _OptionalReplicaSettingsDescriptionTypeDef = TypedDict(
     "_OptionalReplicaSettingsDescriptionTypeDef",
     {
-        "ReplicaStatus": Literal[
-            "CREATING",
-            "CREATION_FAILED",
-            "UPDATING",
-            "DELETING",
-            "ACTIVE",
-            "REGION_DISABLED",
-            "INACCESSIBLE_ENCRYPTION_CREDENTIALS",
-        ],
+        "ReplicaStatus": ReplicaStatus,
         "ReplicaBillingModeSummary": "BillingModeSummaryTypeDef",
         "ReplicaProvisionedReadCapacityUnits": int,
         "ReplicaProvisionedReadCapacityAutoScalingSettings": "AutoScalingSettingsDescriptionTypeDef",
@@ -1183,8 +1149,8 @@ class RestoreSummaryTypeDef(_RequiredRestoreSummaryTypeDef, _OptionalRestoreSumm
 SSEDescriptionTypeDef = TypedDict(
     "SSEDescriptionTypeDef",
     {
-        "Status": Literal["ENABLING", "ENABLED", "DISABLING", "DISABLED", "UPDATING"],
-        "SSEType": Literal["AES256", "KMS"],
+        "Status": SSEStatus,
+        "SSEType": SSEType,
         "KMSMasterKeyArn": str,
         "InaccessibleEncryptionDateTime": datetime,
     },
@@ -1203,12 +1169,7 @@ _RequiredSourceTableDetailsTypeDef = TypedDict(
 )
 _OptionalSourceTableDetailsTypeDef = TypedDict(
     "_OptionalSourceTableDetailsTypeDef",
-    {
-        "TableArn": str,
-        "TableSizeBytes": int,
-        "ItemCount": int,
-        "BillingMode": Literal["PROVISIONED", "PAY_PER_REQUEST"],
-    },
+    {"TableArn": str, "TableSizeBytes": int, "ItemCount": int, "BillingMode": BillingMode},
     total=False,
 )
 
@@ -1235,9 +1196,7 @@ _RequiredStreamSpecificationTypeDef = TypedDict(
     "_RequiredStreamSpecificationTypeDef", {"StreamEnabled": bool}
 )
 _OptionalStreamSpecificationTypeDef = TypedDict(
-    "_OptionalStreamSpecificationTypeDef",
-    {"StreamViewType": Literal["NEW_IMAGE", "OLD_IMAGE", "NEW_AND_OLD_IMAGES", "KEYS_ONLY"]},
-    total=False,
+    "_OptionalStreamSpecificationTypeDef", {"StreamViewType": StreamViewType}, total=False
 )
 
 
@@ -1251,15 +1210,7 @@ TableAutoScalingDescriptionTypeDef = TypedDict(
     "TableAutoScalingDescriptionTypeDef",
     {
         "TableName": str,
-        "TableStatus": Literal[
-            "CREATING",
-            "UPDATING",
-            "DELETING",
-            "ACTIVE",
-            "INACCESSIBLE_ENCRYPTION_CREDENTIALS",
-            "ARCHIVING",
-            "ARCHIVED",
-        ],
+        "TableStatus": TableStatus,
         "Replicas": List["ReplicaAutoScalingDescriptionTypeDef"],
     },
     total=False,
@@ -1271,15 +1222,7 @@ TableDescriptionTypeDef = TypedDict(
         "AttributeDefinitions": List["AttributeDefinitionTypeDef"],
         "TableName": str,
         "KeySchema": List["KeySchemaElementTypeDef"],
-        "TableStatus": Literal[
-            "CREATING",
-            "UPDATING",
-            "DELETING",
-            "ACTIVE",
-            "INACCESSIBLE_ENCRYPTION_CREDENTIALS",
-            "ARCHIVING",
-            "ARCHIVED",
-        ],
+        "TableStatus": TableStatus,
         "CreationDateTime": datetime,
         "ProvisionedThroughput": "ProvisionedThroughputDescriptionTypeDef",
         "TableSizeBytes": int,
@@ -1305,10 +1248,7 @@ TagTypeDef = TypedDict("TagTypeDef", {"Key": str, "Value": str})
 
 TimeToLiveDescriptionTypeDef = TypedDict(
     "TimeToLiveDescriptionTypeDef",
-    {
-        "TimeToLiveStatus": Literal["ENABLING", "DISABLING", "ENABLED", "DISABLED"],
-        "AttributeName": str,
-    },
+    {"TimeToLiveStatus": TimeToLiveStatus, "AttributeName": str},
     total=False,
 )
 
@@ -1392,7 +1332,7 @@ _OptionalUpdateTypeDef = TypedDict(
                 None,
             ],
         ],
-        "ReturnValuesOnConditionCheckFailure": Literal["ALL_OLD", "NONE"],
+        "ReturnValuesOnConditionCheckFailure": ReturnValuesOnConditionCheckFailure,
     },
     total=False,
 )
@@ -1427,7 +1367,7 @@ AttributeValueUpdateTypeDef = TypedDict(
             Dict[str, Any],
             None,
         ],
-        "Action": Literal["ADD", "PUT", "DELETE"],
+        "Action": AttributeAction,
     },
     total=False,
 )
@@ -1520,24 +1460,7 @@ BatchWriteItemOutputTypeDef = TypedDict(
 )
 
 _RequiredConditionTypeDef = TypedDict(
-    "_RequiredConditionTypeDef",
-    {
-        "ComparisonOperator": Literal[
-            "EQ",
-            "NE",
-            "IN",
-            "LE",
-            "LT",
-            "GE",
-            "GT",
-            "BETWEEN",
-            "NOT_NULL",
-            "NULL",
-            "CONTAINS",
-            "NOT_CONTAINS",
-            "BEGINS_WITH",
-        ]
-    },
+    "_RequiredConditionTypeDef", {"ComparisonOperator": ComparisonOperator}
 )
 _OptionalConditionTypeDef = TypedDict(
     "_OptionalConditionTypeDef",
@@ -1652,9 +1575,7 @@ DescribeContributorInsightsOutputTypeDef = TypedDict(
         "TableName": str,
         "IndexName": str,
         "ContributorInsightsRuleList": List[str],
-        "ContributorInsightsStatus": Literal[
-            "ENABLING", "ENABLED", "DISABLING", "DISABLED", "FAILED"
-        ],
+        "ContributorInsightsStatus": ContributorInsightsStatus,
         "LastUpdateDateTime": datetime,
         "FailureException": "FailureExceptionTypeDef",
         "ResponseMetadata": "ResponseMetadata",
@@ -1793,21 +1714,7 @@ ExpectedAttributeValueTypeDef = TypedDict(
             None,
         ],
         "Exists": bool,
-        "ComparisonOperator": Literal[
-            "EQ",
-            "NE",
-            "IN",
-            "LE",
-            "LT",
-            "GE",
-            "GT",
-            "BETWEEN",
-            "NOT_NULL",
-            "NULL",
-            "CONTAINS",
-            "NOT_CONTAINS",
-            "BEGINS_WITH",
-        ],
+        "ComparisonOperator": ComparisonOperator,
         "AttributeValueList": List[
             Union[
                 bytes,
@@ -1929,9 +1836,7 @@ KinesisStreamingDestinationOutputTypeDef = TypedDict(
     {
         "TableName": str,
         "StreamArn": str,
-        "DestinationStatus": Literal[
-            "ENABLING", "ACTIVE", "DISABLING", "DISABLED", "ENABLE_FAILED"
-        ],
+        "DestinationStatus": DestinationStatus,
         "ResponseMetadata": "ResponseMetadata",
     },
     total=False,
@@ -2198,7 +2103,7 @@ RestoreTableToPointInTimeOutputTypeDef = TypedDict(
 
 SSESpecificationTypeDef = TypedDict(
     "SSESpecificationTypeDef",
-    {"Enabled": bool, "SSEType": Literal["AES256", "KMS"], "KMSMasterKeyId": str},
+    {"Enabled": bool, "SSEType": SSEType, "KMSMasterKeyId": str},
     total=False,
 )
 
@@ -2300,9 +2205,7 @@ UpdateContributorInsightsOutputTypeDef = TypedDict(
     {
         "TableName": str,
         "IndexName": str,
-        "ContributorInsightsStatus": Literal[
-            "ENABLING", "ENABLED", "DISABLING", "DISABLED", "FAILED"
-        ],
+        "ContributorInsightsStatus": ContributorInsightsStatus,
         "ResponseMetadata": "ResponseMetadata",
     },
     total=False,
